@@ -9,8 +9,7 @@ Rcpp::List ekpf(const arma::mat& y, SEXP Z, SEXP H,
   const arma::vec& theta, SEXP log_prior_pdf, const arma::vec& known_params,
   const arma::mat& known_tv_params, const unsigned int n_states,
   const unsigned int n_etas,  const arma::uvec& time_varying,
-  const unsigned int nsim, const unsigned int seed,
-  const Rcpp::Function update_fn, const Rcpp::Function prior_fn) {
+  const unsigned int nsim, const unsigned int seed) {
 
 
   Rcpp::XPtr<nvec_fnPtr> xpfun_Z(Z);
@@ -25,7 +24,7 @@ Rcpp::List ekpf(const arma::mat& y, SEXP Z, SEXP H,
 
   ssm_nlg model(y, *xpfun_Z, *xpfun_H, *xpfun_T, *xpfun_R, *xpfun_Zg, *xpfun_Tg,
     *xpfun_a1, *xpfun_P1,  theta, *xpfun_prior, known_params, known_tv_params, n_states, n_etas,
-    time_varying, update_fn, prior_fn, seed);
+    time_varying, seed);
 
   unsigned int m = model.m;
   unsigned n = model.n;
@@ -58,8 +57,7 @@ Rcpp::List ekpf_smoother(const arma::mat& y, SEXP Z, SEXP H,
   const arma::vec& theta, SEXP log_prior_pdf, const arma::vec& known_params,
   const arma::mat& known_tv_params, const unsigned int n_states,
   const unsigned int n_etas,  const arma::uvec& time_varying,
-  const unsigned int nsim, const unsigned int seed,
-  const Rcpp::Function update_fn, const Rcpp::Function prior_fn) {
+  const unsigned int nsim, const unsigned int seed) {
 
   Rcpp::XPtr<nvec_fnPtr> xpfun_Z(Z);
   Rcpp::XPtr<nmat_fnPtr> xpfun_H(H);
@@ -73,7 +71,7 @@ Rcpp::List ekpf_smoother(const arma::mat& y, SEXP Z, SEXP H,
 
   ssm_nlg model(y, *xpfun_Z, *xpfun_H, *xpfun_T, *xpfun_R, *xpfun_Zg, *xpfun_Tg,
     *xpfun_a1, *xpfun_P1,  theta, *xpfun_prior, known_params, known_tv_params, n_states, n_etas,
-    time_varying, update_fn, prior_fn, seed);
+    time_varying, seed);
 
   unsigned int m = model.m;
   unsigned n = model.n;
