@@ -12,6 +12,30 @@ ar1_lg::ar1_lg(const Rcpp::List model, const unsigned int seed) :
 void ar1_lg::update_model(const arma::vec& new_theta) {
   
   
+  T(0, 0, 0) = new_theta(0);
+  R(0, 0, 0) = new_theta(1);
+  if (mu_est) {
+    a1(0) = new_theta(2);
+    C.fill(new_theta(2) * (1.0 - new_theta(0)));
+  }
+  P1(0, 0) = std::pow(new_theta(1), 2) / (1.0 - std::pow(new_theta(0), 2));
+  
+  compute_RR();
+  
+  if(sd_y_est) {
+    H(0) = new_theta(2 + mu_est);
+    HH(0) = H(0);
+  }
+  
+  if(xreg.n_cols > 0) {
+    beta = new_theta.subvec(new_theta.n_elem - xreg.n_cols, new_theta.n_elem - 1);
+    compute_xbeta();
+  }
+  theta = new_theta;
+}
+void ar1_lg::update_model(const arma::vec& new_theta, const Rcpp::Function update_fn) {
+  
+  
   T(0, 0, 0) = new_theta(0);
   R(0, 0, 0) = new_theta(1);
   if (mu_est) {
@@ -34,7 +58,7 @@ void ar1_lg::update_model(const arma::vec& new_theta) {
   theta = new_theta;
 }
 
-double ar1_lg::log_prior_pdf(const arma::vec& x) const {
+double ar1_lg::log_prior_pdf(const arma::vec& x, const Rcpp::Function prior_fn) const {
   
   double log_prior = 0.0;
   
