@@ -24,15 +24,13 @@ ssm_mng::ssm_mng(const Rcpp::List model, const unsigned int seed, const double z
     approx_loglik(0.0), scales(arma::vec(n, arma::fill::zeros)),
     engine(seed), zero_tol(zero_tol),
     RR(arma::cube(m, m, Rtv * (n - 1) + 1)),
-    update_fn(Rcpp::as<Rcpp::Function>(model["update_fn"])), 
-    prior_fn(Rcpp::as<Rcpp::Function>(model["prior_fn"])),
     approx_model(y, Z, arma::cube(p, p, n, arma::fill::zeros), T, R, a1, P1, 
-      D, C, theta, seed + 1, update_fn, prior_fn){
+      D, C, theta, seed + 1){
   compute_RR();
 }
 
 
-void ssm_mng::update_model(const arma::vec& new_theta) {
+void ssm_mng::update_model(const arma::vec& new_theta, const Rcpp::Function update_fn) {
   Rcpp::List model_list = 
     update_fn(Rcpp::NumericVector(new_theta.begin(), new_theta.end()));
   if (model_list.containsElementNamed("Z")) {
@@ -65,7 +63,7 @@ void ssm_mng::update_model(const arma::vec& new_theta) {
   if (approx_state > 0) approx_state = 0;
 }
 
-double ssm_mng::log_prior_pdf(const arma::vec& x) const {
+double ssm_mng::log_prior_pdf(const arma::vec& x, const Rcpp::Function prior_fn) const {
   return Rcpp::as<double>(prior_fn(Rcpp::NumericVector(x.begin(), x.end())));
 }
 
@@ -671,7 +669,7 @@ double ssm_mng::bsf_filter(const unsigned int nsim, arma::cube& alpha,
 
 
 arma::cube ssm_mng::predict_sample(const arma::mat& theta_posterior,
-  const arma::mat& alpha, const unsigned int predict_type) {
+  const arma::mat& alpha, const unsigned int predict_type, const Rcpp::Function update_fn) {
   
   unsigned int d = p;
   if (predict_type == 3) d = m;
@@ -681,7 +679,7 @@ arma::cube ssm_mng::predict_sample(const arma::mat& theta_posterior,
   
   
   for (unsigned int i = 0; i < n_samples; i++) {
-    update_model(theta_posterior.col(i));
+    update_model(theta_posterior.col(i), update_fn);
     a1 = alpha.col(i);
     sample.slice(i) = sample_model(predict_type);
   }
@@ -768,14 +766,14 @@ arma::mat ssm_mng::sample_model(const unsigned int predict_type) {
 
 
 arma::cube ssm_mng::predict_past(const arma::mat& theta_posterior,
-  const arma::cube& alpha, const unsigned int predict_type) {
+  const arma::cube& alpha, const unsigned int predict_type, const Rcpp::Function update_fn) {
   
   unsigned int n_samples = theta_posterior.n_cols;
   arma::cube samples(p, n, n_samples);
   
   std::normal_distribution<> normal(0.0, 1.0);
   for (unsigned int i = 0; i < n_samples; i++) {
-    update_model(theta_posterior.col(i));
+    update_model(theta_posterior.col(i), update_fn);
     arma::mat y(p, n);
     for (unsigned int t = 0; t < n; t++) {
       arma::vec signal = D.col(t * Dtv) + Z.slice(t * Ztv) * alpha.slice(i).col(t);
